@@ -24,10 +24,14 @@ pub enum Error {
     ExpectedInt,
     #[error("Variable not found")]
     VarNotFound,
+    #[error("Function not found")]
+    FnNotFound,
     #[error("Cannot execute a path on a value")]
     PathOnValue,
     #[error("Input is empty in {0}")]
     Empty(&'static str),
+    #[error("Conversion failed: {0}")]
+    Conversion(#[from] Box<dyn std::error::Error>),
 }
 
 pub type Result<T> = std::result::Result<T, Error>;
